import os
import sys
import numpy as np
import scipy as sp

typatm = np.dtype([('typ', 'S2'), ('pos', float, (3,)), ('rad', float), ('id', int)])
cut = 50.0
lig_ele_list = ['C','N','O','S','P','F','Cl','Br','I']
pro_ele_list = ['C','N','O','S']
aa_list = ['ALA','ARG','ASN','ASP','CYS','GLU','GLN','GLY','HIS','HSE','HSD','SEC',
           'ILE','LEU','LYS','MET','PHE','PRO','SER','THR','TRP','TYR','VAL','PYL']

def gettyp( rawtyp ):
	if not rawtyp[1].isalpha():
		typ = ' '+rawtyp[0]
	else:
		typ = rawtyp
	return typ


propath = sys.argv[1]
ligpath = sys.argv[2]
outpath = sys.argv[3]

ligfile = open(ligpath)
profile = open(propath)
lignum = 0
pronum = 0
lines = ligfile.read().splitlines()
for j in range(0,len(lines)):
	line = lines[j]
	if line[0:13] == '@<TRIPOS>ATOM':
		ligstart = j+1
	if line[0:13] == '@<TRIPOS>BOND':
		ligend = j-1
lignum = 0
for j in range(ligstart,ligend+1):
	line = lines[j]
	typ = gettyp(line[47:49])
	if typ.replace(" ","") in lig_ele_list:
		lignum += 1
LIG = np.zeros([lignum], dtype = typatm)
k = 0
for j in range(ligstart,ligend+1):
	line = lines[j]
	if line[8:17] == 'thiophene':
		typ = gettyp(line[48:50])
		x = float(line[18:27]);
		y = float(line[27:37]);
		z = float(line[37:47]);
	else:
		typ = gettyp(line[47:49])
		x = float(line[17:26]);
		y = float(line[26:36]);
		z = float(line[36:46]);
	if typ.replace(" ","") in lig_ele_list:
		LIG[k]['pos'][:] = np.array([x,y,z])
		LIG[k]['typ'] = typ; LIG[k]['id'] = 1
		k += 1

lines = profile.read().splitlines()
for line in lines:
	if line[0:4] == 'ATOM' and line[17:20] in aa_list:
		typ = line[12:14].replace(" ","")
		x = float(line[30:38]); y = float(line[38:46]); z = float(line[46:54])
		for j in range(0,len(LIG)):
			dis = np.linalg.norm(np.array([x,y,z])-LIG[j]['pos'])
			if dis <= cut and typ in pro_ele_list:
				pronum += 1
				break
PRO = np.zeros([pronum], dtype = typatm)
j = 0
for line in lines:
	if line[0:4] == 'ATOM' and line[17:20] in aa_list:
		typ = line[12:14]
		x = float(line[30:38]); y = float(line[38:46]); z = float(line[46:54])
		for k in range(0,len(LIG)):
			dis = np.linalg.norm(np.array([x,y,z])-LIG[k]['pos'])
			if dis <= cut and typ.replace(" ", "") in pro_ele_list:
				PRO[j]['typ'] = typ; PRO[j]['pos'][:] = np.array([x,y,z]);
				PRO[j]['id'] = -1; j+=1
				break
print len(LIG), len(PRO)
outfile = open(outpath, 'w')
np.savez(outfile,PRO=PRO,LIG=LIG)
outfile.close()
